# Find Vortex

# This module finds the Vortex engine if it is
# installed and determines where the include files and libraries
# are. The VORTEX_PATH variable (or environment variable) can be set
# to specify where to look for Vortex. In addition, VORTEX_LIB_PATH
# and VORTEX_INCLUDE_PATH can be set to specify locations for the ode
# library and include files as well.
#
# The following variables are set:
#  VORTEX_LIBRARIES         = List of libraries needed to use Vortex
#  VORTEX_INCLUDE_DIRS      = Include path for Vortex
#  VORTEX_RESOURCE_DIR      = Directory with example Vortex files

include(FindPackageHandleStandardArgs)

if (NOT VORTEX_PATH)
  set(VORTEX_PATH $ENV{VORTEX_PATH})
endif()

find_path(VORTEX_INCLUDE_DIR Vx
    PATHS "${VORTEX_PATH}" "${VORTEX_INCLUDE_PATH}"
    ENV VORTEX_INCLUDE_PATH
    PATH_SUFFIXES include
    DOC "Path to Vortex header files")
mark_as_advanced(VORTEX_INCLUDE_DIR)

set(VORTEX_LIBRARIES "")
# The libraries might not be in the right link order yet. In the Vortex
# example makefiles they use the gcc toolchain-specific linker flags '-(' and
# '-)' to repeatedly search libraries between those flags for symbols. We'd
# like to maintain portability to other toolchains, so we'll try to avoid
# those flags.
foreach(vortexlib VxOSG5-2.8.3 VxPersistence5 VxControllerPersistence5 VxVehiclePersistence5 VxController5 VxGraphics5 VxVehicle5 VxPs5 VxPsExtraOSG5 Vx5)
    string(TOUPPER "${vortexlib}" lib)
    find_library(VORTEX_${lib}_LIBRARY ${vortexlib}
        PATHS "${VORTEX_PATH}" "${VORTEX_LIB_PATH}" ENV VORTEX_LIB_PATH
        PATH_SUFFIXES "" "lib"
        DOC "Path to Vortex ${vortexlib} library")
    list(APPEND VORTEX_LIBRARIES "${VORTEX_${lib}_LIBRARY}")
    mark_as_advanced(VORTEX_${lib}_LIBRARY)
endforeach(vortexlib)

# Try to use the version of OpenSceneGraph that comes with Vortex. System-wide installed
# versions may not be compatible
set(ENV{OSG_DIR} "${VORTEX_PATH}/3rdparty/osg-2.8.3")
set(ENV{OSG_ROOT} "")
find_package(OpenSceneGraph COMPONENTS osg osgViewer osgDB osgFX osgShadow osgGA osgSim osgText osgUtil OpenThreads)

find_library(SDL_LIBRARY SDL)

set(VORTEX_LIBRARIES
    ${VORTEX_LIBRARIES}
    ${OPENSCENEGRAPH_LIBRARIES}
    ${SDL_LIBRARY}
    ${CMAKE_DL_LIBS})
set(VORTEX_INCLUDE_DIRS "${VORTEX_INCLUDE_DIR}" ${OPENSCENEGRAPH_INCLUDE_DIRS})

find_path(VORTEX_RESOURCE_DIR "Util/Plane/ground.flt"
    PATHS "${VORTEX_PATH}/src/resources"
    DOC "Directory with example Vortex files")
mark_as_advanced(VORTEX_RESOURCE_DIR)

find_package_handle_standard_args(Vortex DEFAULT_MSG VORTEX_VX5_LIBRARY VORTEX_INCLUDE_DIR)
